### Name: pcSelect
### Title: PC-Select: Estimate subgraph around a response variable
### Aliases: pcSelect
### Keywords: multivariate models graphs

### ** Examples

p <- 10
## generate and draw random DAG :
set.seed(101)
myDAG <- randomDAG(p, prob = 0.2)
plot(myDAG, main = "randomDAG(10, prob = 0.2)")

## generate 1000 samples of DAG using standard normal error distribution
n <- 1000
d.mat <- rmvDAG(n, myDAG, errDist = "normal")

## let's pretend that the 10th column is the response and the first 9
## columns are explanatory variable. Which of the first 9 variables
## "cause" the tenth variable?
y <- d.mat[,10]
dm <- d.mat[,-10]
pcSelect(d.mat[,10],d.mat[,-10],alpha=0.05)
## You see, that variable 4,5,6 are considered as important
## By inspecting zMin you can also see, that the influence of variable 6
## is very evident from the data (zMin is 21.32, so quite large - as a
## rule
## of thumb for judging what is large, you could use quantiles of the
## Standard Normal Distribution)

## The result should be the same when using pcAlgo
resU <- pcAlgo(d.mat, alpha = 0.05, corMethod = "standard",directed=TRUE)
resU
plot(resU,zvalue.lwd=TRUE)
## as can be seen, the pcAlgo function also finds 4,5,6 as the important
## variables
## Again, variable 6 seems to be very evident from the data



